@@ -1,12 +1,10 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from trytond import backend
 from trytond.model import ModelSQL, ValueMixin, fields
 from trytond.pool import Pool, PoolMeta
-from trytond.tools.multivalue import migrate_property
 
 dunning_procedure = fields.Many2One(
-    'account.dunning.procedure', "Dunning Procedure")
+    'account.dunning.procedure', "Dunning Procedure", ondelete='RESTRICT')
 
 
 class Party(metaclass=PoolMeta):
@@ -31,20 +29,3 @@ class PartyDunningProcedure(ModelSQL, ValueMixin):
     party = fields.Many2One(
         'party.party', "Party", ondelete='CASCADE')
     dunning_procedure = dunning_procedure
-
-    @classmethod
-    def __register__(cls, module_name):
-        exist = backend.TableHandler.table_exist(cls._table)
-
-        super(PartyDunningProcedure, cls).__register__(module_name)
-
-        if not exist:
-            cls._migrate_property([], [], [])
-
-    @classmethod
-    def _migrate_property(cls, field_names, value_names, fields):
-        field_names.append('dunning_procedure')
-        value_names.append('dunning_procedure')
-        migrate_property(
-            'party.party', field_names, cls, value_names,
-            parent='party', fields=fields)
